import { isPlatformBrowser, CommonModule } from '@angular/common';
import { Injectable, EventEmitter, Component, Inject, PLATFORM_ID, ViewChild, Input, Output, InjectionToken, NgModule } from '@angular/core';
import { FormGroup, FormControl, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { AngularFireAuth, AngularFireAuthModule } from '@angular/fire/auth';
import { AngularFirestore, AngularFirestoreModule } from '@angular/fire/firestore';
import { auth } from 'firebase';
import { FirebaseOptionsToken, FirebaseNameOrConfigToken } from '@angular/fire';
import { NgbModule } from '@ng-bootstrap/ng-bootstrap';
import { HttpClientModule } from '@angular/common/http';
import { trigger, transition, query, stagger, animateChild, style, animate } from '@angular/animations';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
/** @type {?} */
const collections = {
    users: 'users',
};
class FirestoreSyncService {
    /**
     * @param {?} afs
     */
    constructor(afs) {
        this.afs = afs;
        // this.afs.firestore.settings({timestampsInSnapshots: true});
    }
    // get timestamp() {
    //     return firebase.firestore.FieldValue.serverTimestamp();
    // }
    /**
     * @param {?} uid
     * @return {?}
     */
    getUserDocRefByUID(uid) {
        return this.afs.doc(`${collections.users}/${uid}`);
    }
    /**
     * @param {?=} queryFn
     * @return {?}
     */
    getUsersCollectionRef(queryFn) {
        return this.afs.collection(`${collections.users}/`, queryFn);
    }
    /**
     * @param {?} uid
     * @return {?}
     */
    deleteUserData(uid) {
        /** @type {?} */
        const userRef = this.getUserDocRefByUID(uid);
        return userRef.delete();
    }
    /**
     * @param {?} user
     * @return {?}
     */
    updateUserData(user) {
        // Sets user$ data to firestore on login
        /** @type {?} */
        const userRef = this.getUserDocRefByUID(user.uid);
        /** @type {?} */
        const data = {
            uid: user.uid,
            email: user.email,
            displayName: user.displayName,
            photoURL: user.photoURL,
            phoneNumber: user.phoneNumber,
            providerId: user.providerId
        };
        return userRef.set(data, { merge: true });
    }
}
FirestoreSyncService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
FirestoreSyncService.ctorParameters = () => [
    { type: AngularFirestore }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
/** @enum {string} */
const Accounts = {
    NONE: 'account',
    CHECK: 'account-check',
    EDIT: 'account-edit',
    OFF: 'account-off',
    REMOVE: 'account-remove',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
class AlertService {
    constructor() {
        this.alerts = [];
        this.onNewAlert = new EventEmitter();
        this.onNewAlert.subscribe((alert) => this.alerts.push(alert));
    }
}
AlertService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
AlertService.ctorParameters = () => [];

var __awaiter = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
// import User = firebase.User;
var 
// import User = firebase.User;
GoogleAuthProvider = auth.GoogleAuthProvider;
var FacebookAuthProvider = auth.FacebookAuthProvider;
var TwitterAuthProvider = auth.TwitterAuthProvider;
var GithubAuthProvider = auth.GithubAuthProvider;
/** @enum {string} */
const AuthProvider = {
    ALL: 'all',
    ANONYMOUS: 'anonymous',
    EmailAndPassword: 'firebase',
    Google: 'google',
    Facebook: 'facebook',
    Twitter: 'twitter',
    Github: 'github',
    PhoneNumber: 'phoneNumber',
};
class AuthProcessService {
    /**
     * @param {?} auth
     * @param {?} alertService
     * @param {?} _fireStoreService
     */
    constructor(auth$$1, alertService, _fireStoreService) {
        this.auth = auth$$1;
        this.alertService = alertService;
        this._fireStoreService = _fireStoreService;
        this.onSuccessEmitter = new EventEmitter();
        this.onErrorEmitter = new EventEmitter();
    }
    /**
     * Reset the password of the user via email
     *
     * @param {?} email - the email to reset
     * @return {?}
     */
    resetPassword(email) {
        this.isLoading = true;
        return this.auth.auth.sendPasswordResetEmail(email)
            .then(() => {
            this.isLoading = false;
            return;
        })
            .catch((error) => {
            this.isLoading = false;
            return this.onErrorEmitter.next(error);
        });
    }
    /**
     * General sign in mechanism to authenticate the users with a firebase project
     * using a traditional way, via username and password or by using an authentication provider
     * like google, facebook, twitter and github
     *
     * @param {?} provider - the provider to authenticate with (google, facebook, twitter, github)
     * @param {?=} email - (optional) the email of user - used only for a traditional sign in
     * @param {?=} password - (optional) the password of user - used only for a traditional sign in
     * @return {?}
     */
    signInWith(provider, email, password) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                this.isLoading = true;
                /** @type {?} */
                let signInResult;
                switch (provider) {
                    case AuthProvider.ANONYMOUS:
                        signInResult = (/** @type {?} */ (yield this.auth.auth.signInAnonymously()));
                        break;
                    case AuthProvider.EmailAndPassword:
                        signInResult = (/** @type {?} */ (yield this.auth.auth.signInWithEmailAndPassword(email, password)));
                        break;
                    case AuthProvider.Google:
                        signInResult = (/** @type {?} */ (yield this.auth.auth.signInWithPopup(new GoogleAuthProvider())));
                        break;
                    case AuthProvider.Facebook:
                        signInResult = (/** @type {?} */ (yield this.auth.auth.signInWithPopup(new FacebookAuthProvider())));
                        break;
                    case AuthProvider.Twitter:
                        signInResult = (/** @type {?} */ (yield this.auth.auth.signInWithPopup(new TwitterAuthProvider())));
                        break;
                    case AuthProvider.Github:
                        signInResult = (/** @type {?} */ (yield this.auth.auth.signInWithPopup(new GithubAuthProvider())));
                        break;
                    default:
                        throw new Error(`${AuthProvider[provider]} is not available as auth provider`);
                }
                yield this.handleSuccess(signInResult);
            }
            catch (err) {
                this.handleError(err);
                console.error(err);
                this.alertService.onNewAlert.emit({
                    id: new Date().getTime(),
                    message: err.message,
                    type: 'danger'
                });
                this.onErrorEmitter.next(err);
            }
            finally {
                this.isLoading = false;
            }
        });
    }
    /**
     * Sign up new users via email and password.
     * After that the user should verify and confirm an email sent via the firebase
     *
     * @param {?} name - the name if the new user
     * @param {?} email - the email if the new user
     * @param {?} password - the password if the new user
     * @return {?}
     */
    signUp(name, email, password) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                this.isLoading = true;
                /** @type {?} */
                const userCredential = yield this.auth.auth.createUserWithEmailAndPassword(email, password);
                /** @type {?} */
                const user = userCredential.user;
                yield this._fireStoreService
                    .getUserDocRefByUID(user.uid)
                    .set((/** @type {?} */ ({
                    uid: user.uid,
                    displayName: name,
                    email: user.email,
                    photoURL: user.photoURL
                })));
                yield user.sendEmailVerification();
                yield this.updateProfile(name, user.photoURL);
                this.emailConfirmationSent = true;
                this.emailToConfirm = email;
                yield this.handleSuccess(userCredential);
            }
            catch (err) {
                console.error(err);
                this.handleError(err);
            }
            finally {
                this.isLoading = false;
            }
        });
    }
    /**
     * Update the profile (name + photo url) of the authenticated user in the
     * firebase authentication feature (not in firestore)
     *
     * @param {?} name - the new name of the authenticated user
     * @param {?} photoURL - the new photo url of the authenticated user
     * @return {?}
     */
    updateProfile(name, photoURL) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.auth.auth.currentUser.updateProfile({ displayName: name, photoURL: photoURL });
        });
    }
    /**
     * @return {?}
     */
    deleteAccount() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.auth.auth.currentUser.delete();
        });
    }
    /**
     * @param {?} user
     * @return {?}
     */
    parseUserInfo(user) {
        return {
            uid: user.uid,
            displayName: user.displayName,
            email: user.email,
            phoneNumber: user.phoneNumber,
            photoURL: user.photoURL,
            providerId: user.providerData.length > 0 ? user.providerData[0].providerId : null
        };
    }
    /**
     * @return {?}
     */
    getUserPhotoUrl() {
        /** @type {?} */
        const user = this.auth.auth.currentUser;
        if (user.photoURL) {
            return user.photoURL;
        }
        else if (user.emailVerified) {
            return this.getPhotoPath(Accounts.CHECK);
        }
        else if (user.isAnonymous) {
            return this.getPhotoPath(Accounts.OFF);
        }
        else {
            return this.getPhotoPath(Accounts.NONE);
        }
    }
    /**
     * @param {?} image
     * @return {?}
     */
    getPhotoPath(image) {
        return `assets/user/${image}.svg`;
    }
    /**
     * @return {?}
     */
    signInWithPhoneNumber() {
        // todo: 3.1.18
    }
    /**
     * @param {?} userCredential
     * @return {?}
     */
    handleSuccess(userCredential) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this._fireStoreService.updateUserData(this.parseUserInfo(userCredential.user));
            this.alertService.onNewAlert.emit({
                id: new Date().getTime(),
                message: `Hallo ${userCredential.user.displayName ? userCredential.user.displayName : ''}!`,
                type: 'success'
            });
            this.onSuccessEmitter.next(userCredential.user);
        });
    }
    /**
     * @param {?} error
     * @return {?}
     */
    handleError(error) {
        this.alertService.onNewAlert.emit({
            id: new Date().getTime(),
            message: error.message,
            type: 'danger'
        });
        console.error(error);
        this.onErrorEmitter.next(error);
    }
}
AuthProcessService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
AuthProcessService.ctorParameters = () => [
    { type: AngularFireAuth },
    { type: AlertService },
    { type: FirestoreSyncService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
/** @type {?} */
const defaultAuthFirebaseUIConfig = {
    // authMethod: 'redirect',
    // authProviders: [new GoogleAuthProvider(), new FacebookAuthProvider(), new TwitterAuthProvider(), new GithubAuthProvider()],
    // onlyEmailPasswordAuth: false,
    toastMessageOnAuthSuccess: true,
    toastMessageOnAuthError: true
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
/** @type {?} */
const EMAIL_REGEX = new RegExp(['^(([^<>()[\\]\\\.,;:\\s@\"]+(\\.[^<>()\\[\\]\\\.,;:\\s@\"]+)*)',
    '|(".+"))@((\\[[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.',
    '[0-9]{1,3}\])|(([a-zA-Z\\-0-9]+\\.)+',
    '[a-zA-Z]{2,}))$'].join(''));
class AuthComponent {
    /**
     * @param {?} platformId
     * @param {?} auth
     * @param {?} authProcess
     * @param {?} alertService
     */
    constructor(platformId, auth$$1, authProcess, alertService) {
        this.platformId = platformId;
        this.auth = auth$$1;
        this.authProcess = authProcess;
        this.alertService = alertService;
        this.providers = AuthProvider.ALL; //  google, facebook, twitter, github as array or all as one single string
        //  google, facebook, twitter, github as array or all as one single string
        this.guestEnabled = true;
        this.authProvider = AuthProvider;
        this.authenticationError = false;
        this.passReset = false;
        this.authProviders = AuthProvider;
        this.onSuccess = authProcess.onSuccessEmitter;
        this.onError = authProcess.onErrorEmitter;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (isPlatformBrowser(this.platformId)) {
            this.onErrorSubscription = this.onError.subscribe(() => this.authenticationError = true);
        }
        this._initSignInFormGroupBuilder();
        this._initSignUpFormGroupBuilder();
        this._initResetPasswordFormGroupBuilder();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.onErrorSubscription) {
            this.onErrorSubscription.unsubscribe();
        }
    }
    /**
     * @return {?}
     */
    get color() {
        return this.authenticationError ? 'warn' : 'primary';
    }
    /**
     * @return {?}
     */
    resetPassword() {
        this.authProcess.resetPassword(this.resetPasswordEmailFormControl.value)
            .then(() => this.passReset = true);
    }
    /**
     * @return {?}
     */
    selectResetPasswordTab() {
        this.passwordResetWished = true;
        setTimeout(() => {
            this.tabs.select('reset_password');
        }, 1);
    }
    /**
     * @return {?}
     */
    _initSignInFormGroupBuilder() {
        this.signInFormGroup = new FormGroup({});
        this.signInFormGroup.registerControl('email', this.signInEmailFormControl = new FormControl('', [
            Validators.required,
            Validators.pattern(EMAIL_REGEX)
        ]));
        this.signInFormGroup.registerControl('password', this.sigInPasswordFormControl = new FormControl('', [
            Validators.required,
            Validators.minLength(6),
            Validators.maxLength(25),
        ]));
    }
    /**
     * @return {?}
     */
    _initSignUpFormGroupBuilder() {
        this.signUpFormGroup = new FormGroup({
            name: this.sigUpNameFormControl = new FormControl('', [
                Validators.required,
                Validators.minLength(2),
                Validators.maxLength(30),
            ]),
            email: this.sigUpEmailFormControl = new FormControl('', [
                Validators.required,
                Validators.pattern(EMAIL_REGEX)
            ]),
            password: this.sigUpPasswordFormControl = new FormControl('', [
                Validators.required,
                Validators.minLength(6),
                Validators.maxLength(25),
            ])
        });
    }
    /**
     * @return {?}
     */
    _initResetPasswordFormGroupBuilder() {
        this.resetPasswordFormGroup = new FormGroup({
            email: this.resetPasswordEmailFormControl = new FormControl('', [
                Validators.required,
                Validators.pattern(EMAIL_REGEX)
            ])
        });
    }
}
AuthComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngb-auth-firebaseui',
                template: `
    <ngb-auth-firebaseui-progress-bar *ngIf="authProcess.isLoading" class="mb-2">
    </ngb-auth-firebaseui-progress-bar>
    <ngb-tabset #tabs>
      <!--Reset password tab-->
      <ngb-tab *ngIf="passwordResetWished" title="Reset Password" id="reset_password">
        <ng-template ngbTabContent>
          <form #resetPasswordForm="ngForm"
                class="mt-3"
                [formGroup]="resetPasswordFormGroup"
                (ngSubmit)="resetPasswordFormGroup.valid && resetPassword()">

            <div class="form-group is-invalid">
              <label for="validationResetEmail">E-mail</label>
              <input class="form-control"
                     [class.is-valid]="resetPasswordEmailFormControl.valid && resetPasswordEmailFormControl.dirty"
                     [class.is-invalid]="resetPasswordEmailFormControl.errors  && (resetPasswordEmailFormControl.dirty || resetPasswordForm.submitted)"
                     id="validationResetEmail"
                     [formControl]="resetPasswordEmailFormControl"
                     placeholder="E-mail"
                     type="email"
                     aria-describedby="inputGroupPrepend3"
                     required>

              <!--error msgs-->
              <div class="invalid-feedback"
                   *ngIf="resetPasswordEmailFormControl.errors
                   && (resetPasswordEmailFormControl.dirty || resetPasswordEmailFormControl.touched || resetPasswordForm.submitted)">
                <p *ngIf="resetPasswordEmailFormControl.hasError('required')">
                  E-mail is required
                </p>
                <p *ngIf="resetPasswordEmailFormControl.hasError('pattern')">
                  Please enter a valid e-mail address
                </p>
              </div>
            </div>

            <div class="text-center">
              <button class="btn btn-primary"
                      type="submit"
                      [disabled]="passReset">
                Reset
              </button>
            </div>

            <div *ngIf="passReset" class="mt-2 mx-auto">
              <ngb-alert type="success">
                Reset requested. Check your <strong>e-mail</strong> instructions!
              </ngb-alert>
            </div>

          </form>
        </ng-template>
      </ngb-tab>

      <!--Sign in tab-->
      <ngb-tab>
        <ng-template ngbTabTitle>Sign in</ng-template>
        <ng-template ngbTabContent>
          <form #signInPasswordForm="ngForm"
                class="mt-3"
                [formGroup]="signInFormGroup"
                (ngSubmit)="signInFormGroup.valid &&
                  authProcess.signInWith
                  (authProviders.EmailAndPassword,signInFormGroup.value.email,signInFormGroup.value.password)">

            <div class="form-group">
              <label for="validationSignInEmail">E-mail</label>
              <div class="input-group">
                <input class="form-control"
                       [class.is-valid]="signInEmailFormControl.valid && signInEmailFormControl.dirty"
                       [class.is-invalid]="signInEmailFormControl.errors
                       && (signInEmailFormControl.dirty || signInPasswordForm.submitted)"
                       id="validationSignInEmail"
                       [formControl]="signInEmailFormControl"
                       placeholder="E-mail"
                       type="email"
                       aria-describedby="inputGroupPrepend3"
                       required>

                <!--error msgs-->
                <div class="invalid-feedback"
                     *ngIf="signInEmailFormControl.errors
                     && (signInEmailFormControl.dirty || signInEmailFormControl.touched || signInPasswordForm.submitted)">
                  <p *ngIf="signInEmailFormControl.hasError('required')">
                    E-mail is required
                  </p>
                  <p *ngIf="signInEmailFormControl.hasError('pattern')">
                    Please enter a valid e-mail address
                  </p>
                </div>
              </div>
            </div>

            <div class="form-group">
              <label for="validationSignInPassword">Password</label>
              <div class="input-group">
                <input class="form-control"
                       [class.is-valid]="sigInPasswordFormControl.valid && sigInPasswordFormControl.dirty"
                       [class.is-invalid]="sigInPasswordFormControl.errors && (sigInPasswordFormControl.dirty || signInPasswordForm.submitted)"

                       id="validationSignInPassword"
                       type="password"
                       placeholder="password"
                       name="password"
                       [formControl]="sigInPasswordFormControl"
                       aria-describedby="inputGroupPrepend4"
                       required>

                <!--<small id="passwordHelpBlock" class="form-text text-muted">-->
                <!--Your password must be 8-25 characters long, contain letters and numbers,-->
                <!--and must not contain spaces, special characters, or emoji.-->
                <!--</small>-->

                <div class="invalid-feedback"
                     *ngIf="sigInPasswordFormControl.errors
                     && (sigInPasswordFormControl.dirty || sigInPasswordFormControl.touched || signInPasswordForm.submitted)">
                  <p *ngIf="sigInPasswordFormControl.hasError('required')">
                    Please do not forget the password
                  </p>
                  <p *ngIf="sigInPasswordFormControl.hasError('minlength')">
                    The password must be at least 6 characters
                    long.
                  </p>
                  <p *ngIf="sigInPasswordFormControl.hasError('maxlength')">
                    The password can not be longer than 25 characters.
                  </p>
                </div>

              </div>
            </div>


            <div class="container">
              <div class="row justify-content-between">
                <div class="align-self-start">
                  <button class="btn btn-primary"
                          type="submit">
                    Log in
                  </button>
                </div>
                <div class="align-self-end">
                  <button *ngIf="guestEnabled"
                          type="button"
                          class="btn btn-outline-secondary"
                          (click)="selectResetPasswordTab()">
                    Forgot Password?
                  </button>
                </div>
              </div>
            </div>
          </form>
        </ng-template>
      </ngb-tab>

      <!--Register - sign up tab-->
      <ngb-tab>
        <ng-template ngbTabTitle>Register</ng-template>
        <ng-template ngbTabContent>
          <ng-container *ngIf="!authProcess.emailConfirmationSent;then register else confirm"></ng-container>
          <ng-template #register>
            <form #signUpPasswordForm="ngForm"
                  class="mt-3"
                  [formGroup]="signUpFormGroup"
                  (ngSubmit)="signUpFormGroup.valid &&
              authProcess.signUp
              (signUpFormGroup.value.name,signUpFormGroup.value.email,signUpFormGroup.value.password)">
              <div class="form-group">
                <label for="validationName">First name</label>
                <input class="form-control"
                       [class.is-valid]="sigUpNameFormControl.valid && sigUpNameFormControl.dirty"
                       [class.is-invalid]="sigUpNameFormControl.errors
                      && (sigUpNameFormControl.dirty || signUpPasswordForm.submitted)"
                       id="validationName"
                       type="text"
                       minlength="2"
                       maxlength="30"
                       [formControl]="sigUpNameFormControl"
                       placeholder="Name"
                       required>
                <div class="invalid-feedback"
                     *ngIf="sigUpNameFormControl.errors
                   && (sigUpNameFormControl.dirty || sigUpNameFormControl.touched || signUpPasswordForm.submitted)">
                  <p *ngIf="sigUpNameFormControl.hasError('required')">
                    Name is required
                  </p>
                  <p *ngIf="sigUpNameFormControl.hasError('minlength')">
                    The name is too short!
                  </p>
                  <p *ngIf="sigUpNameFormControl.hasError('maxlength')">
                    The name is too long!
                  </p>
                </div>
              </div>
              <div class="form-group">
                <label for="validationRegisterEmail">E-mail</label>
                <div class="input-group">
                  <input class="form-control"
                         [class.is-valid]="sigUpEmailFormControl.valid && sigUpEmailFormControl.dirty"
                         [class.is-invalid]="sigUpEmailFormControl.errors
                       && (sigUpEmailFormControl.dirty || signUpPasswordForm.submitted)"
                         id="validationRegisterEmail"
                         [formControl]="sigUpEmailFormControl"
                         placeholder="E-mail"
                         type="email"
                         aria-describedby="inputGroupPrepend3"
                         required>

                  <!--error msgs-->
                  <div class="invalid-feedback"
                       *ngIf="sigUpEmailFormControl.errors
                     && (sigUpEmailFormControl.dirty || sigUpEmailFormControl.touched || signUpPasswordForm.submitted)">
                    <p *ngIf="sigUpEmailFormControl.hasError('required')">
                      E-mail is required
                    </p>
                    <p *ngIf="sigUpEmailFormControl.hasError('pattern')">
                      Please enter a valid e-mail address
                    </p>
                  </div>

                </div>
              </div>

              <div class="form-group">
                <label for="validationRegisterPassword">Password</label>
                <div class="input-group">
                  <input class="form-control"
                         [class.is-valid]="sigUpPasswordFormControl.valid && sigUpPasswordFormControl.dirty"
                         [class.is-invalid]="sigUpPasswordFormControl.errors
                       && (sigUpPasswordFormControl.dirty || signUpPasswordForm.submitted)"
                         id="validationRegisterPassword"
                         type="password"
                         placeholder="password"
                         name="password"
                         [formControl]="sigUpPasswordFormControl"
                         aria-describedby="inputGroupPrepend4"
                         required>

                  <!--<small id="passwordHelpBlock" class="form-text text-muted">-->
                  <!--Your password must be 8-25 characters long, contain letters and numbers,-->
                  <!--and must not contain spaces, special characters, or emoji.-->
                  <!--</small>-->

                  <div class="invalid-feedback"
                       *ngIf="sigUpPasswordFormControl.errors
                      && (sigUpPasswordFormControl.dirty || sigUpPasswordFormControl.touched) || signUpPasswordForm.submitted">
                    <p *ngIf="sigUpPasswordFormControl.hasError('required')">
                      Please do not forget the password
                    </p>
                    <p *ngIf="sigUpPasswordFormControl.hasError('minlength')">
                      The password must be at least 6 characters
                      long.
                    </p>
                    <p *ngIf="sigUpPasswordFormControl.hasError('maxlength')">
                      The password can not be longer than 25 characters.
                    </p>
                  </div>

                </div>
              </div>

              <!--<div class="form-group">-->
              <!--<div class="form-check">-->
              <!--<input class="form-check-input is-invalid" type="checkbox" value="" id="invalidCheck3" required>-->
              <!--<label class="form-check-label" for="invalidCheck3">-->
              <!--Agree to terms and conditions-->
              <!--</label>-->
              <!--<div class="invalid-feedback">-->
              <!--You must agree before submitting.-->
              <!--</div>-->
              <!--</div>-->
              <!--</div>-->

              <div class="container">
                <div class="row justify-content-between">
                  <div class="align-self-start">
                    <button class="btn btn-primary"
                            type="submit">
                      Register
                    </button>
                  </div>
                  <div class="align-self-end">
                    <button *ngIf="guestEnabled"
                            class="btn btn-outline-secondary"
                            (click)="authProcess.signInWith(authProvider.ANONYMOUS)">
                      <i class="fa fa-fingerprint"></i>
                      continue as guest
                    </button>
                  </div>
                </div>
              </div>
            </form>

          </ng-template>
          <!--confirm template-->
          <ng-template #confirm>
            <ngb-auth-firebaseui-email-confirmation [email]="authProcess.emailToConfirm">
            </ngb-auth-firebaseui-email-confirmation>
          </ng-template>
        </ng-template>

      </ngb-tab>
    </ngb-tabset>

    <ngb-auth-firebaseui-providers class="mt-2"></ngb-auth-firebaseui-providers>
    <ngb-alerts-container class="mt-2" [alerts]="alertService.alerts"></ngb-alerts-container>
  `,
                styles: [`
    :host{display:block}.mat-card{margin:2rem}.space-top{margin-top:.5rem}.full-width{width:100%}.cut-text{text-overflow:ellipsis;overflow:hidden;white-space:nowrap}
  `]
            },] },
];
/** @nocollapse */
AuthComponent.ctorParameters = () => [
    { type: Object, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] },
    { type: AngularFireAuth },
    { type: AuthProcessService },
    { type: AlertService }
];
AuthComponent.propDecorators = {
    tabs: [{ type: ViewChild, args: ['tabs',] }],
    providers: [{ type: Input }],
    guestEnabled: [{ type: Input }],
    onSuccess: [{ type: Output }],
    onError: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
class EmailConfirmationComponent {
    constructor() {
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
EmailConfirmationComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngb-auth-firebaseui-email-confirmation',
                template: `
    <div class="card">
      <div class="card-body">
        <h5 class="card-title">Confirm your e-mail address!</h5>
        <h6 class="card-subtitle mb-2 text-muted">
          A confirmation e-mail has been sent to
          <b><strong>{{email}}</strong></b>
        </h6>

        <p class="card-text">Check your inbox and click on the link <strong>"Confirm my e-mail"</strong> to confirm your
          e-mail
          address.</p>

        <a href="#" class="card-link">Go back to the sign up page</a>
      </div>
    </div>
  `,
                styles: [`
    :host{display:block}.material-icons{font-size:4rem}.mat-icon{height:4rem;width:4rem;color:rgba(0,0,0,.54)}.title{font-size:20px;margin-top:16px}.subtitle{margin:16px auto;max-width:300px;color:rgba(0,0,0,.54);font-size:15px;text-align:center}.subtitle p{display:block;-webkit-margin-before:1em;-webkit-margin-after:1em;-webkit-margin-start:0;-webkit-margin-end:0}
  `]
            },] },
];
/** @nocollapse */
EmailConfirmationComponent.ctorParameters = () => [];
EmailConfirmationComponent.propDecorators = {
    email: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
class ProgressBarComponent {
}
ProgressBarComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngb-auth-firebaseui-progress-bar',
                template: `
    <div class="progress mt-2">
      <div class="progress-bar progress-bar-striped progress-bar-animated" role="progressbar"
           aria-valuenow="75" aria-valuemin="0" aria-valuemax="100"></div>
    </div>
  `,
                styles: [`
    :host{display:block}.progress-bar{width:100%}
  `]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
/** @enum {string} */
const Layout = {
    ROW: 'row',
    COLUMN: 'column',
};
class AuthProvidersComponent {
    /**
     * @param {?} authProcess
     */
    constructor(authProcess) {
        this.authProcess = authProcess;
        this.layout = Layout.ROW;
        this.providers = AuthProvider.ALL; //  google, facebook, twitter, github
        //  google, facebook, twitter, github
        this.authProvider = AuthProvider;
    }
}
AuthProvidersComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngb-auth-firebaseui-providers',
                template: `
    <div class="container">

      <div class="row ">
        <button *ngIf="providers === authProvider.ALL || providers.includes(authProvider.Google)"
                class="btn btn-google my-1 mx-sm-0 col-md-3 col-sm-6 col-xs-12 text-center"
                (click)="authProcess.signInWith(authProvider.Google)">
          <span class="fa fa-google"></span>
          Google
        </button>
        <button *ngIf="providers === authProvider.ALL || providers.includes(authProvider.Facebook)"
                class="btn btn-facebook my-1 mx-sm-0 col-md-3 col-sm-6 col-xs-12 text-center"
                (click)="authProcess.signInWith(authProvider.Facebook)">
          <span class="fa fa-facebook"></span>
          Facebook
        </button>
        <button *ngIf="providers === authProvider.ALL || providers.includes(authProvider.Twitter)"
                class="btn btn-twitter my-1 mx-sm-0 col-md-3 col-sm-6 col-xs-12 text-center"
                (click)="authProcess.signInWith(authProvider.Twitter)">
          <span class="fa fa-twitter"></span>
          Twitter
        </button>
        <button *ngIf="providers === authProvider.ALL || providers.includes(authProvider.Github)"
                class="btn btn-github my-1 mx-sm-0 col-md-3 col-sm-6 col-xs-12 text-center"
                (click)="authProcess.signInWith(authProvider.Github)">
          <span class="fa fa-github"></span>
          GitHub
        </button>
      </div>

    </div>
  `,
                styles: [`
    :host{display:block}.space-full-xs{width:100%;margin:.4rem}.btn{color:#fff}.btn-google{background-color:#db4437}.btn-google:hover{background-color:#c23321}.btn-facebook{background-color:#385899}.btn-facebook:hover{background-color:#2d4373}.btn-twitter{background-color:#1da1f2}.btn-twitter:hover{background-color:#2795e9}.btn-github{background-color:#444}.btn-github:hover{background-color:#000}
  `]
            },] },
];
/** @nocollapse */
AuthProvidersComponent.ctorParameters = () => [
    { type: AuthProcessService }
];
AuthProvidersComponent.propDecorators = {
    layout: [{ type: Input }],
    providers: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
class NgbAlertsContainerComponent {
    constructor() {
        this.alerts = [];
    }
    /**
     * @param {?} alert
     * @return {?}
     */
    closeAlert(alert) {
        /** @type {?} */
        const index = this.alerts.indexOf(alert);
        this.alerts.splice(index, 1);
    }
}
NgbAlertsContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngb-alerts-container',
                template: `
    <div @alerts *ngFor="let alert of alerts">
      <ngb-alert [type]="alert.type" (close)="closeAlert(alert)">{{ alert.message }}</ngb-alert>
    </div>
  `,
                styles: [`
    :host{display:block}
  `],
                animations: [
                    // nice stagger effect when showing existing elements
                    trigger('list', [
                        transition(':enter', [
                            // child animation selector + stagger
                            query('@alerts', stagger(300, animateChild()))
                        ]),
                    ]),
                    trigger('alerts', [
                        // cubic-bezier for a tiny bouncing feel
                        transition(':enter', [
                            style({ transform: 'scale(0.5)', opacity: 0 }),
                            animate('1s cubic-bezier(.8,-0.6,0.2,1.5)', style({ transform: 'scale(1)', opacity: 1 }))
                        ]),
                        transition(':leave', [
                            style({ transform: 'scale(1)', opacity: 1, height: '*' }),
                            animate('1s cubic-bezier(.8,-0.6,0.2,1.5)', style({ transform: 'scale(0.5)', opacity: 0, height: '0px', margin: '0px' }))
                        ]),
                    ])
                ]
            },] },
];
NgbAlertsContainerComponent.propDecorators = {
    alerts: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */
/** @type {?} */
const NgBootstrapAuthFirebaseUIConfigToken = new InjectionToken('NgBootstrapAuthFirebaseUIConfig');
class NgbAuthFirebaseUIModule {
    /**
     * @param {?} configFactory
     * @param {?=} appNameFactory
     * @param {?=} config
     * @return {?}
     */
    static forRoot(configFactory, appNameFactory, config = defaultAuthFirebaseUIConfig) {
        return {
            ngModule: NgbAuthFirebaseUIModule,
            providers: [
                {
                    provide: FirebaseOptionsToken,
                    useValue: configFactory
                },
                {
                    provide: FirebaseNameOrConfigToken,
                    useFactory: appNameFactory
                },
                {
                    provide: NgBootstrapAuthFirebaseUIConfigToken,
                    useValue: config
                },
                AuthProcessService,
                FirestoreSyncService,
                AlertService
            ],
        };
    }
}
NgbAuthFirebaseUIModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    NgbModule,
                    HttpClientModule,
                    FormsModule,
                    ReactiveFormsModule,
                    AngularFireAuthModule,
                    AngularFirestoreModule
                ],
                exports: [
                    AuthComponent,
                    AuthProvidersComponent,
                    EmailConfirmationComponent,
                    NgbAlertsContainerComponent,
                    ProgressBarComponent,
                    AngularFireAuthModule,
                    AngularFirestoreModule
                ],
                declarations: [
                    AuthComponent,
                    AuthProvidersComponent,
                    EmailConfirmationComponent,
                    ProgressBarComponent,
                    NgbAlertsContainerComponent
                ]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,uselessCode} checked by tsc
 */

export { AuthComponent, EmailConfirmationComponent, ProgressBarComponent, AuthProvidersComponent, NgbAlertsContainerComponent, AuthProcessService, AuthProvider, FirestoreSyncService, AlertService, NgBootstrapAuthFirebaseUIConfigToken, NgbAuthFirebaseUIModule, defaultAuthFirebaseUIConfig as ɵa };
//# sourceMappingURL=ng-bootstrap.js.map
